clear maplemex
syms tau q q1 q2 q3 p1 p2 p3 real
%lambda = 1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%               Symbolic manipulation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Hper = Hp([q1 q2 q3], [p1 p2 p3], epsilon1, epsilon2, epsilon3, epsilon4, epsilon5, Hp1, Hp2, Hp3, Hp4, Hp5);
dHp_q1 = diff(Hper,q1);
dHp_q2 = diff(Hper,q2);
dHp_q3 = diff(Hper,q3);
dHp_p1 = diff(Hper,p1);
dHp_p2 = diff(Hper,p2);
dHp_p3 = diff(Hper,p3);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Write to file and integrate the differential equations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fid = fopen( 'StandardMethod/StandDiffEq.m', 'wt');
fprintf(fid, 'function dotW = StandDiffEq(tau,W)\n');
if strcmp(get(handles.waitbars, 'Checked'),'on')
    fprintf(fid, 'global pick tau_total\n');              %%%%%%%%      waitbar
    fprintf(fid, 'if tau > pick + tau_total/100;\n');     %%%%%%%%      waitbar
    fprintf(fid, '    waitbar(tau/tau_total);\n');        %%%%%%%%      waitbar
    fprintf(fid, '    pick = tau;\n');                    %%%%%%%%      waitbar
    fprintf(fid, 'end\n');                                %%%%%%%%      waitbar
end
fprintf(fid, 'dotW = zeros(8,1);\n');
%fprintf(fid, 'global lambda;\n');
fprintf(fid, '%%\n%% SUBSTITUTIONS\n%%\n');
fprintf(fid, ' q1 = W(1);\n q2 = W(2);\n q3 = W(3);\n p1 = W(4);\n p2 = W(5);\n p3 = W(6);\n');
fprintf(fid, ' q = sqrt(q1^2+q2^2+q3^2);\n');
fprintf(fid, '%%\n%% EQUATIONS\n%%\n');
fprintf(fid, ' dotW(1) = %s;\n dotW(2) = %s;\n dotW(3) = %s;\n dotW(4) = %s;\n dotW(5) = %s;\n dotW(6) = %s;\n dotW(7) = 0;\n dotW(8) = 0;\n',...
    char(p1+dHp_p1), char(p2+dHp_p2), char(p3+dHp_p3), char(-q1/q^3-dHp_q1), char(-q2/q^3-dHp_q2), char(-q3/q^3-dHp_q3));
fclose(fid);

if strcmp(ODE, 'Tom') == 1
    if strcmp(get(handles.warningbox, 'Checked'),'on')
        warndlg(sprintf(['You have selected a fixed-step integrator.\n',...
            'Please, keep in mind that its use is not advisable in the Standard\n',...
            ' Integration method, which in general requires an adaptative step.\n',...
            'Be sure that the problem is very regular and the eccentricity small..']),...
            'Fixed-step integrator');
    end
    met = str2num(get(handles.edit_met,'String'));
%    Order = str2num(get(handles.edit_Order,'String'));
    StepSize = 2*pi*sm_ax_o^(3/2)*str2num(get(handles.edit_StepSize,'String'));
    RelTolNewt = str2num(get(handles.edit_RelTolNewt,'String'));
    Itnlmax = str2num(get(handles.edit_Itnlmax,'String'));
    
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       global pick                                              %%%%%     waitbar
       h = waitbar(0,'Please wait..., KEPLER is calculating.'); %%%%%     waitbar
       pick = -tau_total/100;                                   %%%%%     waitbar
    end
    
    tom_options = tomgset('met',met,'Order',10,'StepSize',StepSize,...
            'RelTolNewt',RelTolNewt,'Vectorized','off',...
            'Itnlmax',Itnlmax,'Stats_step','off','Stats','off');
    tic 
    sol = tomgm('StandDiffEq', [0 2*pi*sm_ax_o^(3/2)*tau_total], [q_vec_o'; p_vec_o'; 0; 0], tom_options);
    W = sol.y';
    t_c = sol.x;
    t_elaps = toc;
    t_elaps = num2str(t_elaps);      
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       close(h)                                                 %%%%%     waitbar
    end

    if strcmp(get(handles.perform, 'Checked'),'on')
        if strcmp(num2str(perfid), '')
            perfid = fopen( 'Perform/Perform.txt', 'wt');
            fprintf(perfid, '*************************************************************************************************\n');
        end
        fprintf(perfid, '                                Standard method          \n\n');
        fprintf(perfid, ['ODE solver Tom, Cycle number ',num2str(tau_total),...
                 ', Step size ',num2str(StepSize/(2*pi*sm_ax_o^(3/2))),...
                 ', Integration time ',t_elaps,' sec.\n']);
        fprintf(perfid, '*************************************************************************************************\n');
    end
elseif (strcmp(ODE, 'RungeKutta4') == 1) | (strcmp(ODE, 'RungeKutta5') == 1)
    if strcmp(get(handles.warningbox, 'Checked'),'on')
        warndlg(sprintf(['You have selected a fixed-step integrator.\n',...
            'Please, keep in mind that its use is not advisable in the Standard\n',...
            ' Integration method, which in general requires an adaptative step.\n',...
            'Be sure that the problem is very regular and the eccentricity small..']),...
            'Fixed-step integrator');
    end
    StepSize = str2num(get(handles.edit_FixedStepSize,'String'));  
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       global pick                                              %%%%%     waitbar
       h = waitbar(0,'Please wait..., KEPLER is calculating.'); %%%%%     waitbar
       pick = -tau_total/100;                                   %%%%%     waitbar
    end
    t_c = (0 : 2*pi*StepSize : 2*pi*sm_ax_o^(3/2)*tau_total)';
    tic             
    W = eval([ODE, '(@StandDiffEq, t_c,  [q_vec_o''; p_vec_o''; 0; 0])']);
    t_elaps = toc;
    t_elaps = num2str(t_elaps);    
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       close(h)                                                 %%%%%     waitbar
    end
    
    if strcmp(get(handles.perform, 'Checked'),'on')
        if strcmp(num2str(perfid), '')
            perfid = fopen( 'Perform/Perform.txt', 'wt');
            fprintf(perfid, '*************************************************************************************************\n');
        end
        fprintf(perfid, '                             Standard method          \n\n');
        fprintf(perfid, ['ODE solver: ',ODE,', Cycle number: ',num2str(tau_total),...
                 ', Step size ',num2str(StepSize),...
                 ', Integration time: ',t_elaps,' sec.\n']);
        fprintf(perfid, '*************************************************************************************************\n');
    end
   
elseif (strcmp(ODE, 'IRKGauss') == 1)
    if strcmp(get(handles.warningbox, 'Checked'),'on')
        warndlg(sprintf(['You have selected a fixed-step integrator.\n',...
            'Please, keep in mind that its use is not advisable in the Standard\n',...
            ' Integration method, which in general requires an adaptative step.\n',...
            'Be sure that the problem is very regular and the eccentricity small..']),...
            'Fixed-step integrator');
    end
    
    StepSize = str2num(get(handles.edit_FixedStepSize,'String'));
    opt.method = str2num(get(handles.edit_IRKMeth,'String'));
    
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       global pick                                              %%%%%     waitbar
       h = waitbar(0,'Please wait..., KEPLER is calculating.'); %%%%%     waitbar
       pick = -tau_total/100;                                   %%%%%     waitbar
    end
    opt.nstep = tau_total/StepSize;    
    tic
    [t_c,W] = eval([ODE, '(@StandDiffEq, [0 2*pi*sm_ax_o^(3/2)*tau_total], [q_vec_o''; p_vec_o''; 0; 0], opt)']);
    t_elaps = num2str(toc);
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       close(h)                                                 %%%%%     waitbar
    end
    
    if strcmp(get(handles.perform, 'Checked'),'on')
        if strcmp(num2str(perfid), '')
            perfid = fopen( 'Perform/Perform.txt', 'wt');
            fprintf(perfid, '*************************************************************************************************\n');
        end
        fprintf(perfid, '                             Standard method          \n\n');
        fprintf(perfid, ['ODE solver: ',ODE,', Cycle number: ',num2str(tau_total),...
                 ', Integration time: ',t_elaps,' sec.\n']);
        fprintf(perfid, '*************************************************************************************************\n');
    end
    
else
    Rel_Tol = str2num(get(handles.edit_RelTol,'String'));
    Abs_Tol = str2num(get(handles.edit_AbsTol,'String'));
    Init_Step = str2num(get(handles.edit_InitialStep,'String'));
    Max_Step = str2num(get(handles.edit_MaxStep,'String'));
    OutStep = get(handles.edit_OutputStep,'String');
    if isequal(str2num(OutStep), []) == 1
        Output_Step = '';
    else
        Output_Step = [':','2*pi*sm_ax_o^(3/2)*',OutStep,':'];
    end
    
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       global pick                                              %%%%%     waitbar
       h = waitbar(0,'Please wait..., KEPLER is calculating.'); %%%%%     waitbar
       pick = -tau_total/100;                                   %%%%%     waitbar
    end
    
    options = odeset('InitialStep',[Init_Step], 'Maxstep',[Max_Step],...
                 'RelTol',[Rel_Tol], 'AbsTol',[Abs_Tol]);
    tic
    [t_c,W] = eval([ODE, '(''StandDiffEq'', [0 ',Output_Step,' 2*pi*sm_ax_o^(3/2)*tau_total], [q_vec_o''; p_vec_o''; 0; 0], options)']);
    t_elaps = toc;
    t_elaps = num2str(t_elaps); 
    if strcmp(get(handles.waitbars, 'Checked'),'on')
       close(h)                                                 %%%%%     waitbar
    end
  
    if strcmp(get(handles.perform, 'Checked'),'on')
        if strcmp(num2str(perfid), '')
            perfid = fopen( 'Perform/Perform.txt', 'wt');
            fprintf(perfid, '*************************************************************************************************\n');
        end
        fprintf(perfid, '                               Standard method          \n\n');
        fprintf(perfid, ['ODE solver ',ODE,', Cycle number ',num2str(tau_total),...
                 ', Relative tolerance ',num2str(Rel_Tol),...
                 ', Integration time ',t_elaps,' sec.\n']);
        fprintf(perfid, '*************************************************************************************************\n');
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate Trajectories
step_total = size(W,1);
step_i = floor(tau_i/tau_total*step_total)+1;
step_f = floor(tau_f/tau_total*step_total);
t = 1/(2*pi)*t_c(step_i:step_f);
%
q_vec = W(step_i:step_f,1:3);
p_vec = W(step_i:step_f,4:6);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%